==========
Components
==========

This section provides high-level descriptions of the main components of django-oscar.

Contents:

.. toctree::
   :maxdepth: 2

   components/offers
   components/checkout
   components/shipping
   components/analytics
   components/promotions
